Name:           liblouisutdml
Version:        1.7.0
Release:        4%{?dist}
Summary:        Braille transcription library for UTDML documents
Group:          System Environment/Libraries
License:        LGPLv3+
URL:            http://abilitiessoft.com
Source0:        http://abilitiessoft.com/%{name}-%{version}.tar.gz

BuildRequires:  ant
BuildRequires:  help2man
BuildRequires:  java-devel >= 1:1.6.0
BuildRequires:  jpackage-utils
BuildRequires:  liblouis-devel >= 2.2.0
BuildRequires:  libxml2-devel
BuildRequires:  texinfo-tex


# gnulib is a copylib that has been granted an exception from the no-bundled-libraries policy
# http://fedoraproject.org/wiki/Packaging:No_Bundled_Libraries#Copylibs
Provides: bundled(gnulib) = 20091111

%description
This is a library intended to provide complete braille transcription services
for UTDML (Unified Tactile Document Markup Language) documents. It translates 
into appropriate braille codes and formats according to its style sheet and 
the specifications in the document.

liblouisutdml is the successor of liblouisxml.


%package devel
Summary: Development files for %{name}
Group: Development/Libraries
Requires: %{name} = %{version}-%{release}

%description devel
%{name} is a braille transcription library for UTDML (Unified Tactile
Document Markup Language) documents. The %{name}-devel package contains
libraries and header files for developing applications that use %{name}.


%package utils
Summary: Utilities that convert various file formats into braille
Group: Applications/Text
License: GPLv3+
Requires: antiword

%description utils
This package provides the following command-line utilities to convert from 
several file formats to braille:
* file2brl: translates XML or text files into embosser-ready braille files
* msword2brl: translates Microsoft Word files into braille files
* pdf2brl: translates PDF files into braille files
* rtf2brl: translates RTF files into braille files


%package java
Summary: Java language bindings for %{name}
Group: Development/Languages
BuildArch: noarch
Requires: %{name} = %{version}-%{release}
Requires: java >= 1:1.6.0
Requires: jpackage-utils


%description java
%{name} is a braille transcription library for UTDML (Unified Tactile 
Document Markup Language) documents. This package provides the Java language
binding for %{name}.


%package doc
Summary: Documentation of the library and the corresponding utilities
Group: Documentation
BuildArch: noarch
Requires: %{name} = %{version}-%{release}
Requires(post): info
Requires(preun): info

%description doc
%{name} is a braille transcription library for UTDML (Unified Tactile
Document Markup Language) documents. This package contains the user and
developer documentation of the library and the command-line utilities
provided by %{name}-utils.


%prep
%setup -q


%build
for i in -I/usr/lib/jvm/java/include{,/linux}; do
  java_inc="$java_inc $i" 
done
%configure --disable-static CPPFLAGS="$java_inc"
make %{?_smp_mflags}
make -C doc liblouisutdml.pdf

cd java
ant


%install
make install DESTDIR=%{buildroot}
rm -f %{buildroot}/%{_infodir}/dir
rm -f %{buildroot}/%{_libdir}/liblouisutdml.la
rm -f %{buildroot}/%{_bindir}/lbx_devonly
rm -rf %{buildroot}/%{_defaultdocdir}/liblouisutdml

install -d %{buildroot}%{_javadir}
install -D -p java/j%{name}.jar %{buildroot}%{_javadir}/%{name}.jar
ln -s %{_javadir}/%{name}.jar %{buildroot}%{_javadir}/j%{name}.jar


%post -p /sbin/ldconfig

%postun -p /sbin/ldconfig

%post doc 
/sbin/install-info %{_infodir}/%{name}.info %{_infodir}/dir || :

%preun doc
if [ $1 = 0 ] ; then
  /sbin/install-info --delete %{_infodir}/%{name}.info %{_infodir}/dir || :
fi


%files
%defattr(-,root,root,-)
%doc AUTHORS ChangeLog README NEWS COPYING.LIB
%{_libdir}/%{name}.so.*
%{_datadir}/%{name}/


%files devel
%defattr(-,root,root,-)
%{_includedir}/%{name}/
%{_libdir}/%{name}.so
%{_libdir}/pkgconfig/%{name}.pc


%files utils
%defattr(-,root,root,-)
%doc COPYING
%{_bindir}/*2brl
%{_mandir}/man1/*2brl.1*
# lbu_devonly segfaults, so excluding it temporarily
# http://code.google.com/p/liblouisutdml/issues/detail?id=1
%exclude %{_bindir}/lbu_devonly


%files java
%defattr(-,root,root,-)
%{_javadir}/%{name}.jar
%{_javadir}/j%{name}.jar


%files doc
%defattr(-,root,root,-)
%doc doc/copyright-notice 
%doc doc/%{name}.{html,txt,pdf}
%{_infodir}/%{name}.info.*


%changelog
* Mon Apr 04 2011 Martin Gieseking <martin.gieseking@uos.de> 1.7.0-4
- Made -doc subpackage depend on base package.

* Fri Apr 01 2011 Martin Gieseking <martin.gieseking@uos.de> 1.7.0-3
- Dropped buildroot stuff.
- Added Requires: antiword to the -utils package as it's needed by msword2brl.
- Added Requires: jpackage-utils to the -java package.
- Excluded lbu_devonly because it segfaults.
- Moved documentation to -doc subpackage.

* Tue Mar 22 2011 Martin Gieseking <martin.gieseking@uos.de> 1.7.0-2
- Added missing BR: texinfo-tex.
- Added version info to Provides: bundled(gnulib).

* Tue Feb 15 2011 Martin Gieseking <martin.gieseking@uos.de> 1.7.0-1
- Initial Fedora package.
